/*
 * Simplified implementation of a dynamic list of int8_ts.
 * Interface file.
 * By Daniel Meja V.
 */

#ifndef __LIST_H__
#define __LIST_H__

#include <stdint.h>

struct list_st{
	int8_t *values;
	unsigned int size;
	unsigned int max_size;
};

typedef struct list_st *list_t;

/*
 * Creates and returns a list with the
 * specified initial max size
 */
list_t list_create(unsigned int initial_max_size);

/*
 * Adds value to the end of the list.
 */
void list_add(list_t list, int8_t value);


/*
 * Sets the element at pos with the specified value.
 * pos must be less than the list size.
 * Returns -1 if error
 */
int list_set(list_t list, unsigned int pos, int8_t value);

/*
 * Gets the element at pos
 * pos must be less than the list size
 * otherwise an invalid -1 is returned
 */
int8_t list_get(list_t list, unsigned int pos);

/*
 * Returns the size of the list
 */
unsigned int list_size(list_t list);

/*
 * Frees the list
 */
void list_free(list_t list);











#endif
