/*
 * Strokes representation and functions
 * Implementation file.
 * By Daniel Meja V.
 */

#include <stdlib.h>
#include "strokes.h"
#include "gestures.h"


#define DEFAULT_INITIAL_NUM_STROKES 2
#define DEFAULT_DELTAS_SIZE 20

/*
 * Creates an array of strokes from an array of raw data
 * and returns a reference to it.
 */
stroke_t * strokes_create(gesture_raw_unit_t data[], int data_size, int *num_strokes) {
	int i, data_ix = 0, max_strokes = DEFAULT_INITIAL_NUM_STROKES;
	int num_zeros;
	stroke_t *strokes = (void *)malloc(DEFAULT_INITIAL_NUM_STROKES *
												sizeof(stroke_t));
	for (i = 0; ; i++) {
		if (i == max_strokes) { // Reached array limit
			max_strokes<<=1;
			strokes = (void *)realloc(strokes, max_strokes*sizeof(stroke_t));
		}

		// Assign initial position
		(*(strokes + i)).x_initial = data[data_ix].xpos;
		(*(strokes + i)).y_initial = data[data_ix].ypos;

		// Create delta lists
		(*(strokes + i)).x_deltas = list_create(DEFAULT_DELTAS_SIZE);
		(*(strokes + i)).y_deltas = list_create(DEFAULT_DELTAS_SIZE);
		data_ix++;

		// Assign delta lists
		while(valid_touch(data[data_ix]) && data_ix < data_size) {
			list_add((*(strokes + i)).x_deltas, data[data_ix].xpos - data[data_ix-1].xpos);
			list_add((*(strokes + i)).y_deltas, data[data_ix].ypos - data[data_ix-1].ypos);
			data_ix++;
		}

		// Data finished
		if (data_ix >= data_size) {
			(*(strokes + i)).wait_time = -1;
			break;
		}

		// Assign wait time
		for (num_zeros = 0; valid_touch(data[data_ix]) == 0 && data_ix<data_size; num_zeros++){
			data_ix++;
		}

		(*(strokes + i)).wait_time = num_zeros;

		// In theory, data shouldn't be over in a wait (trailing zeros removed)
		// But just in case..
		if (data_ix >= data_size)
			break;


	}
	*num_strokes = i + 1;
	return strokes;

}


/*
 * Frees the strokes structure and everything contained on it
 */
void strokes_free(stroke_t *strokes, int size) {
	int i;
	for (i = 0; i < size; i++) {
		list_free((*(strokes + i)).x_deltas);
		list_free((*(strokes + i)).y_deltas);
	}
	free(strokes);
}

// PRIVATE FUNCTIONS



