/*
 * Strokes representation and functions
 * Interface file.
 * By Daniel Meja V.
 */

#ifndef __STROKES_H__
#define __STROKES_H__

#include "gestures.h"
#include "list.h"
/*
 * Representation of a stroke
 */
typedef struct {
	// Initial position
	byte x_initial;
	byte y_initial;

	// List of delta movements for every point in the stroke
	list_t x_deltas;
	list_t y_deltas;

	// Average z press value in all the stroke
	//byte z_average;

	// Wait time after the stroke (-1 for the last stroke in the gesture)
	byte wait_time;
} stroke_t;


/*
 * Creates an array of strokes from an array of raw data
 * and returns a reference to it.
 */
stroke_t * strokes_create(gesture_raw_unit_t data[], int data_size, int *num_strokes);

/*
 * Frees the strokes structure and everything contained on it
 */
void strokes_free(stroke_t *strokes, int size);


#endif
